Class: Aws::Personalize::Types::BatchInferenceJob

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

Contains information on a batch inference job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_inference_job_arn ⇒ String

The Amazon Resource Name (ARN) of the batch inference job.

Returns:

  • (String)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#batch_inference_job_config ⇒ Types::BatchInferenceJobConfig

A string to string map of the configuration details of a batch inference job.



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#batch_inference_job_mode ⇒ String

The job's mode.

Returns:

  • (String)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The time at which the batch inference job was created.

Returns:

  • (Time)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If the batch inference job failed, the reason for the failure.

Returns:

  • (String)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#filter_arn ⇒ String

The ARN of the filter used on the batch inference job.

Returns:

  • (String)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_input ⇒ Types::BatchInferenceJobInput

The Amazon S3 path that leads to the input data used to generate the batch inference job.



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_name ⇒ String

The name of the batch inference job.

Returns:

  • (String)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_output ⇒ Types::BatchInferenceJobOutput

The Amazon S3 bucket that contains the output data generated by the batch inference job.



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The time at which the batch inference job was last updated.

Returns:

  • (Time)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#num_results ⇒ Integer

The number of recommendations generated by the batch inference job. This number includes the error messages generated for failed input records.

Returns:

  • (Integer)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The ARN of the Amazon Identity and Access Management (IAM) role that requested the batch inference job.

Returns:

  • (String)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#solution_version_arn ⇒ String

The Amazon Resource Name (ARN) of the solution version from which the batch inference job was created.

Returns:

  • (String)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the batch inference job. The status is one of the following values:

  • PENDING

  • IN PROGRESS

  • ACTIVE

  • CREATE FAILED

Returns:

  • (String)


247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#theme_generation_config ⇒ Types::ThemeGenerationConfig

The job's theme generation settings.



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/aws-sdk-personalize/types.rb', line 247

class BatchInferenceJob < Struct.new(
  :job_name,
  :batch_inference_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :batch_inference_job_config,
  :role_arn,
  :batch_inference_job_mode,
  :theme_generation_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end