Class: Aws::Personalize::Types::BatchSegmentJob

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

Contains information on a batch segment job.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#batch_segment_job_arn ⇒ String

The Amazon Resource Name (ARN) of the batch segment job.

Returns:

  • (String)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#creation_date_time ⇒ Time

The time at which the batch segment job was created.

Returns:

  • (Time)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If the batch segment job failed, the reason for the failure.

Returns:

  • (String)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#filter_arn ⇒ String

The ARN of the filter used on the batch segment job.

Returns:

  • (String)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_input ⇒ Types::BatchSegmentJobInput

The Amazon S3 path that leads to the input data used to generate the batch segment job.



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_name ⇒ String

The name of the batch segment job.

Returns:

  • (String)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#job_output ⇒ Types::BatchSegmentJobOutput

The Amazon S3 bucket that contains the output data generated by the batch segment job.



461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The time at which the batch segment job last updated.

Returns:

  • (Time)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#num_results ⇒ Integer

The number of predicted users generated by the batch segment job for each line of input data. The maximum number of users per segment is 5 million.

Returns:

  • (Integer)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The ARN of the Amazon Identity and Access Management (IAM) role that requested the batch segment job.

Returns:

  • (String)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#solution_version_arn ⇒ String

The Amazon Resource Name (ARN) of the solution version used by the batch segment job to generate batch segments.

Returns:

  • (String)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the batch segment job. The status is one of the following values:

  • PENDING

  • IN PROGRESS

  • ACTIVE

  • CREATE FAILED

Returns:

  • (String)


461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/aws-sdk-personalize/types.rb', line 461

class BatchSegmentJob < Struct.new(
  :job_name,
  :batch_segment_job_arn,
  :filter_arn,
  :failure_reason,
  :solution_version_arn,
  :num_results,
  :job_input,
  :job_output,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end