Class: Aws::Personalize::Types::CreateDatasetExportJobRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Personalize::Types::CreateDatasetExportJobRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-personalize/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset that contains the data to export.
-
#ingestion_mode ⇒ String
The data to export, based on how you imported the data.
-
#job_name ⇒ String
The name for the dataset export job.
-
#job_output ⇒ Types::DatasetExportJobOutput
The path to the Amazon S3 bucket where the job’s output is stored.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM service role that has permissions to add data to your output Amazon S3 bucket.
-
#tags ⇒ Array<Types::Tag>
A list of [tags] to apply to the dataset export job.
Instance Attribute Details
#dataset_arn ⇒ String
The Amazon Resource Name (ARN) of the dataset that contains the data to export.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/aws-sdk-personalize/types.rb', line 1208 class CreateDatasetExportJobRequest < Struct.new( :job_name, :dataset_arn, :ingestion_mode, :role_arn, :job_output, :tags) SENSITIVE = [] include Aws::Structure end |
#ingestion_mode ⇒ String
The data to export, based on how you imported the data. You can choose to export only BULK data that you imported using a dataset import job, only PUT data that you imported incrementally (using the console, PutEvents, PutUsers and PutItems operations), or ALL for both types. The default value is PUT.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/aws-sdk-personalize/types.rb', line 1208 class CreateDatasetExportJobRequest < Struct.new( :job_name, :dataset_arn, :ingestion_mode, :role_arn, :job_output, :tags) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The name for the dataset export job.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/aws-sdk-personalize/types.rb', line 1208 class CreateDatasetExportJobRequest < Struct.new( :job_name, :dataset_arn, :ingestion_mode, :role_arn, :job_output, :tags) SENSITIVE = [] include Aws::Structure end |
#job_output ⇒ Types::DatasetExportJobOutput
The path to the Amazon S3 bucket where the job’s output is stored.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/aws-sdk-personalize/types.rb', line 1208 class CreateDatasetExportJobRequest < Struct.new( :job_name, :dataset_arn, :ingestion_mode, :role_arn, :job_output, :tags) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM service role that has permissions to add data to your output Amazon S3 bucket.
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/aws-sdk-personalize/types.rb', line 1208 class CreateDatasetExportJobRequest < Struct.new( :job_name, :dataset_arn, :ingestion_mode, :role_arn, :job_output, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of [tags] to apply to the dataset export job.
[1]: docs.aws.amazon.com/personalize/latest/dg/tagging-resources.html
1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 |
# File 'lib/aws-sdk-personalize/types.rb', line 1208 class CreateDatasetExportJobRequest < Struct.new( :job_name, :dataset_arn, :ingestion_mode, :role_arn, :job_output, :tags) SENSITIVE = [] include Aws::Structure end |