Class: Aws::Personalize::Types::CreateDatasetGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain ⇒ String

The domain of the dataset group. Specify a domain to create a Domain dataset group. The domain you specify determines the default schemas for datasets and the use cases available for recommenders. If you don't specify a domain, you create a Custom dataset group with solution versions that you deploy with a campaign.

Returns:

  • (String)


1264
1265
1266
1267
1268
1269
1270
1271
1272
# File 'lib/aws-sdk-personalize/types.rb', line 1264

class CreateDatasetGroupRequest < Struct.new(
  :name,
  :role_arn,
  :kms_key_arn,
  :domain,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arn ⇒ String

The Amazon Resource Name (ARN) of a Key Management Service (KMS) key used to encrypt the datasets.

Returns:

  • (String)


1264
1265
1266
1267
1268
1269
1270
1271
1272
# File 'lib/aws-sdk-personalize/types.rb', line 1264

class CreateDatasetGroupRequest < Struct.new(
  :name,
  :role_arn,
  :kms_key_arn,
  :domain,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name for the new dataset group.

Returns:

  • (String)


1264
1265
1266
1267
1268
1269
1270
1271
1272
# File 'lib/aws-sdk-personalize/types.rb', line 1264

class CreateDatasetGroupRequest < Struct.new(
  :name,
  :role_arn,
  :kms_key_arn,
  :domain,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The ARN of the Identity and Access Management (IAM) role that has permissions to access the Key Management Service (KMS) key. Supplying an IAM role is only valid when also specifying a KMS key.

Returns:

  • (String)


1264
1265
1266
1267
1268
1269
1270
1271
1272
# File 'lib/aws-sdk-personalize/types.rb', line 1264

class CreateDatasetGroupRequest < Struct.new(
  :name,
  :role_arn,
  :kms_key_arn,
  :domain,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A list of tags to apply to the dataset group.

Returns:



1264
1265
1266
1267
1268
1269
1270
1271
1272
# File 'lib/aws-sdk-personalize/types.rb', line 1264

class CreateDatasetGroupRequest < Struct.new(
  :name,
  :role_arn,
  :kms_key_arn,
  :domain,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end