Class: Aws::Personalize::Types::CreateEventTrackerRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dataset_group_arn ⇒ String

The Amazon Resource Name (ARN) of the dataset group that receives the event data.

Returns:

  • (String)


1441
1442
1443
1444
1445
1446
1447
# File 'lib/aws-sdk-personalize/types.rb', line 1441

class CreateEventTrackerRequest < Struct.new(
  :name,
  :dataset_group_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name for the event tracker.

Returns:

  • (String)


1441
1442
1443
1444
1445
1446
1447
# File 'lib/aws-sdk-personalize/types.rb', line 1441

class CreateEventTrackerRequest < Struct.new(
  :name,
  :dataset_group_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A list of tags to apply to the event tracker.

Returns:



1441
1442
1443
1444
1445
1446
1447
# File 'lib/aws-sdk-personalize/types.rb', line 1441

class CreateEventTrackerRequest < Struct.new(
  :name,
  :dataset_group_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end