Class: Aws::Personalize::Types::CreateSolutionVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Personalize::Types::CreateSolutionVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-personalize/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the solution version.
-
#solution_arn ⇒ String
The Amazon Resource Name (ARN) of the solution containing the training configuration information.
-
#tags ⇒ Array<Types::Tag>
A list of [tags] to apply to the solution version.
-
#training_mode ⇒ String
The scope of training to be performed when creating the solution version.
Instance Attribute Details
#name ⇒ String
The name of the solution version.
1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-personalize/types.rb', line 1842 class CreateSolutionVersionRequest < Struct.new( :name, :solution_arn, :training_mode, :tags) SENSITIVE = [] include Aws::Structure end |
#solution_arn ⇒ String
The Amazon Resource Name (ARN) of the solution containing the training configuration information.
1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-personalize/types.rb', line 1842 class CreateSolutionVersionRequest < Struct.new( :name, :solution_arn, :training_mode, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of [tags] to apply to the solution version.
[1]: docs.aws.amazon.com/personalize/latest/dg/tagging-resources.html
1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-personalize/types.rb', line 1842 class CreateSolutionVersionRequest < Struct.new( :name, :solution_arn, :training_mode, :tags) SENSITIVE = [] include Aws::Structure end |
#training_mode ⇒ String
The scope of training to be performed when creating the solution version. The default is FULL. This creates a completely new model based on the entirety of the training data from the datasets in your dataset group.
If you use [User-Personalization], you can specify a training mode of UPDATE. This updates the model to consider new items for recommendations. It is not a full retraining. You should still complete a full retraining weekly. If you specify UPDATE, Amazon Personalize will stop automatic updates for the solution version. To resume updates, create a new solution with training mode set to FULL and deploy it in a campaign. For more information about automatic updates, see [Automatic updates].
The UPDATE option can only be used when you already have an active solution version created from the input solution using the FULL option and the input solution was trained with the
- User-Personalization][1
-
recipe or the legacy [HRNN-Coldstart]
recipe.
[1]: docs.aws.amazon.com/personalize/latest/dg/native-recipe-new-item-USER_PERSONALIZATION.html [2]: docs.aws.amazon.com/personalize/latest/dg/use-case-recipe-features.html#maintaining-with-automatic-updates [3]: docs.aws.amazon.com/personalize/latest/dg/native-recipe-hrnn-coldstart.html
1842 1843 1844 1845 1846 1847 1848 1849 |
# File 'lib/aws-sdk-personalize/types.rb', line 1842 class CreateSolutionVersionRequest < Struct.new( :name, :solution_arn, :training_mode, :tags) SENSITIVE = [] include Aws::Structure end |