Class: Aws::Personalize::Types::Dataset

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

Provides metadata for a dataset.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_time ⇒ Time

The creation date and time (in Unix time) of the dataset.

Returns:

  • (Time)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_arn ⇒ String

The Amazon Resource Name (ARN) of the dataset that you want metadata for.

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_group_arn ⇒ String

The Amazon Resource Name (ARN) of the dataset group.

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_type ⇒ String

One of the following values:

  • Interactions

  • Items

  • Users

  • Actions

  • Action_Interactions

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

A time stamp that shows when the dataset was updated.

Returns:

  • (Time)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#latest_dataset_update ⇒ Types::DatasetUpdateSummary

Describes the latest update to the dataset.



2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the dataset.

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#schema_arn ⇒ String

The ARN of the associated schema.

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the dataset.

A dataset can be in one of the following states:

  • CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED

  • DELETE PENDING > DELETE IN_PROGRESS

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end

#tracking_id ⇒ String

The ID of the event tracker for an Action interactions dataset. You specify the tracker's ID in the PutActionInteractions API operation. Amazon Personalize uses it to direct new data to the Action interactions dataset in your dataset group.

Returns:

  • (String)


2090
2091
2092
2093
2094
2095
2096
2097
2098
2099
2100
2101
2102
2103
# File 'lib/aws-sdk-personalize/types.rb', line 2090

class Dataset < Struct.new(
  :name,
  :dataset_arn,
  :dataset_group_arn,
  :dataset_type,
  :schema_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :latest_dataset_update,
  :tracking_id)
  SENSITIVE = []
  include Aws::Structure
end