Class: Aws::Personalize::Types::DatasetGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

A dataset group is a collection of related datasets (Item interactions, Users, Items, Actions, Action interactions). You create a dataset group by calling CreateDatasetGroup. You then create a dataset and add it to a dataset group by calling CreateDataset. The dataset group is used to create and train a solution by calling CreateSolution. A dataset group can contain only one of each type of dataset.

You can specify an Key Management Service (KMS) key to encrypt the datasets in the group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_time ⇒ Time

The creation date and time (in Unix time) of the dataset group.

Returns:

  • (Time)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_group_arn ⇒ String

The Amazon Resource Name (ARN) of the dataset group.

Returns:

  • (String)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#domain ⇒ String

The domain of a Domain dataset group.

Returns:

  • (String)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

If creating a dataset group fails, provides the reason why.

Returns:

  • (String)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arn ⇒ String

The Amazon Resource Name (ARN) of the Key Management Service (KMS) key used to encrypt the datasets.

Returns:

  • (String)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The last update date and time (in Unix time) of the dataset group.

Returns:

  • (Time)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the dataset group.

Returns:

  • (String)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#role_arn ⇒ String

The ARN of the Identity and Access Management (IAM) role that has permissions to access the Key Management Service (KMS) key. Supplying an IAM role is only valid when also specifying a KMS key.

Returns:

  • (String)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the dataset group.

A dataset group can be in one of the following states:

  • CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED

  • DELETE PENDING

Returns:

  • (String)


2324
2325
2326
2327
2328
2329
2330
2331
2332
2333
2334
2335
2336
# File 'lib/aws-sdk-personalize/types.rb', line 2324

class DatasetGroup < Struct.new(
  :name,
  :dataset_group_arn,
  :status,
  :role_arn,
  :kms_key_arn,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :domain)
  SENSITIVE = []
  include Aws::Structure
end