Class: Aws::Personalize::Types::DatasetImportJob

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

Describes a job that imports training data from a data source (Amazon S3 bucket) to an Amazon Personalize dataset. For more information, see [CreateDatasetImportJob].

A dataset import job can be in one of the following states:

  • CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED

^

[1]: docs.aws.amazon.com/personalize/latest/dg/API_CreateDatasetImportJob.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_timeTime

The creation date and time (in Unix time) of the dataset import job.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#data_sourceTypes::DataSource

The Amazon S3 bucket that contains the training data to import.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_arnString

The Amazon Resource Name (ARN) of the dataset that receives the imported data.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_import_job_arnString

The ARN of the dataset import job.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

If a dataset import job fails, provides the reason why.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#import_modeString

The import mode used by the dataset import job to import new records.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#job_nameString

The name of the import job.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_timeTime

The date and time (in Unix time) the dataset was last updated.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#publish_attribution_metrics_to_s3Boolean

Whether the job publishes metrics to Amazon S3 for a metric attribution.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The ARN of the IAM role that has permissions to read from the Amazon S3 data source.



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the dataset import job.

A dataset import job can be in one of the following states:

  • CREATE PENDING &gt; CREATE IN_PROGRESS &gt; ACTIVE -or- CREATE FAILED

^



2467
2468
2469
2470
2471
2472
2473
2474
2475
2476
2477
2478
2479
2480
2481
# File 'lib/aws-sdk-personalize/types.rb', line 2467

class DatasetImportJob < Struct.new(
  :job_name,
  :dataset_import_job_arn,
  :dataset_arn,
  :data_source,
  :role_arn,
  :status,
  :creation_date_time,
  :last_updated_date_time,
  :failure_reason,
  :import_mode,
  :publish_attribution_metrics_to_s3)
  SENSITIVE = []
  include Aws::Structure
end