Class: Aws::Personalize::Types::RecommenderSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

Provides a summary of the properties of the recommender.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_date_time ⇒ Time

The date and time (in Unix format) that the recommender was created.



5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-personalize/types.rb', line 5169

class RecommenderSummary < Struct.new(
  :name,
  :recommender_arn,
  :dataset_group_arn,
  :recipe_arn,
  :recommender_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#dataset_group_arn ⇒ String

The Amazon Resource Name (ARN) of the Domain dataset group that contains the recommender.



5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-personalize/types.rb', line 5169

class RecommenderSummary < Struct.new(
  :name,
  :recommender_arn,
  :dataset_group_arn,
  :recipe_arn,
  :recommender_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_date_time ⇒ Time

The date and time (in Unix format) that the recommender was last updated.



5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-personalize/types.rb', line 5169

class RecommenderSummary < Struct.new(
  :name,
  :recommender_arn,
  :dataset_group_arn,
  :recipe_arn,
  :recommender_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the recommender.



5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-personalize/types.rb', line 5169

class RecommenderSummary < Struct.new(
  :name,
  :recommender_arn,
  :dataset_group_arn,
  :recipe_arn,
  :recommender_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#recipe_arn ⇒ String

The Amazon Resource Name (ARN) of the recipe (Domain dataset group use case) that the recommender was created for.



5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-personalize/types.rb', line 5169

class RecommenderSummary < Struct.new(
  :name,
  :recommender_arn,
  :dataset_group_arn,
  :recipe_arn,
  :recommender_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_arn ⇒ String

The Amazon Resource Name (ARN) of the recommender.



5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-personalize/types.rb', line 5169

class RecommenderSummary < Struct.new(
  :name,
  :recommender_arn,
  :dataset_group_arn,
  :recipe_arn,
  :recommender_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#recommender_config ⇒ Types::RecommenderConfig

The configuration details of the recommender.



5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-personalize/types.rb', line 5169

class RecommenderSummary < Struct.new(
  :name,
  :recommender_arn,
  :dataset_group_arn,
  :recipe_arn,
  :recommender_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the recommender. A recommender can be in one of the following states:

  • CREATE PENDING > CREATE IN_PROGRESS > ACTIVE -or- CREATE FAILED

  • STOP PENDING > STOP IN_PROGRESS > INACTIVE > START PENDING > START IN_PROGRESS > ACTIVE

  • DELETE PENDING > DELETE IN_PROGRESS



5169
5170
5171
5172
5173
5174
5175
5176
5177
5178
5179
5180
# File 'lib/aws-sdk-personalize/types.rb', line 5169

class RecommenderSummary < Struct.new(
  :name,
  :recommender_arn,
  :dataset_group_arn,
  :recipe_arn,
  :recommender_config,
  :status,
  :creation_date_time,
  :last_updated_date_time)
  SENSITIVE = []
  include Aws::Structure
end