Class: Aws::Personalize::Types::UpdateCampaignRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-personalize/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#campaign_arnString

The Amazon Resource Name (ARN) of the campaign.



6099
6100
6101
6102
6103
6104
6105
6106
# File 'lib/aws-sdk-personalize/types.rb', line 6099

class UpdateCampaignRequest < Struct.new(
  :campaign_arn,
  :solution_version_arn,
  :min_provisioned_tps,
  :campaign_config)
  SENSITIVE = []
  include Aws::Structure
end

#campaign_configTypes::CampaignConfig

The configuration details of a campaign.



6099
6100
6101
6102
6103
6104
6105
6106
# File 'lib/aws-sdk-personalize/types.rb', line 6099

class UpdateCampaignRequest < Struct.new(
  :campaign_arn,
  :solution_version_arn,
  :min_provisioned_tps,
  :campaign_config)
  SENSITIVE = []
  include Aws::Structure
end

#min_provisioned_tpsInteger

Specifies the requested minimum provisioned transactions (recommendations) per second that Amazon Personalize will support. A high minProvisionedTPS will increase your bill. We recommend starting with 1 for minProvisionedTPS (the default). Track your usage using Amazon CloudWatch metrics, and increase the minProvisionedTPS as necessary.



6099
6100
6101
6102
6103
6104
6105
6106
# File 'lib/aws-sdk-personalize/types.rb', line 6099

class UpdateCampaignRequest < Struct.new(
  :campaign_arn,
  :solution_version_arn,
  :min_provisioned_tps,
  :campaign_config)
  SENSITIVE = []
  include Aws::Structure
end

#solution_version_arnString

The Amazon Resource Name (ARN) of a new model to deploy. To specify the latest solution version of your solution, specify the ARN of your solution in ‘SolutionArn/$LATEST` format. You must use this format if you set syncWithLatestSolutionVersion to True in the [CampaignConfig].

To deploy a model that isn’t the latest solution version of your solution, specify the ARN of the solution version.

For more information about automatic campaign updates, see [Enabling automatic campaign updates].

[1]: docs.aws.amazon.com/personalize/latest/dg/API_CampaignConfig.html [2]: docs.aws.amazon.com/personalize/latest/dg/campaigns.html#create-campaign-automatic-latest-sv-update



6099
6100
6101
6102
6103
6104
6105
6106
# File 'lib/aws-sdk-personalize/types.rb', line 6099

class UpdateCampaignRequest < Struct.new(
  :campaign_arn,
  :solution_version_arn,
  :min_provisioned_tps,
  :campaign_config)
  SENSITIVE = []
  include Aws::Structure
end